﻿ //The PathwayObj used by Fleet.fla

class PathwayObj {
	/* Variables */
	var pathwaysSelectionArea:MovieClip;  	//A pointer to the Pathways_Selection_Area MovieClip containing this object
	var pathwayMC:MovieClip;   				//A pointer to the Pathways_mc MovieClip corresponding to this object
	var vehiclesList:Array;					//Data provider for pathwayMC.pathway_area.area.vehicle_cb
	var fuelsList:Array;					//Data provider for pathwayMC.pathway_area.area.fuel_cb
	var pathwaysList:Array;					//Data provider for pathwayMC.pathway_area.area.pathway_cb
	var pathwaysXML:XML;					//XML file containing WtW pathways results
	var _index:Number;						//The current index of this object in the pathwaysArray associated with the parent Pathways_Selection_Area MovieClip
	var dragBoxMC:MovieClip;				//A pointer to a movie clip temporarily created when this object is dragged
	var cbListener:Object = new Object();
	var abbrev:String = "Unspecified Pathway";
	var color:Number = 0xFFFFFF;			//hex format number corresponding to a color for this pathway (for use in graphing); default color is white
	var colorsArray:Array;					//array of possible colors to chose from
	var previousDepth:Number;				//used by color picker event handlers
	//results variables (in Btu or grams per vehicle mile travelled):
	var displayRelative:Boolean = false;	//indicates whether or not to display absolute or realtive results (relative to baseline pathway's restults)											
	var petrolEnergy:Number;	
	var fossilEnergy:Number;
	var otherEnergy:Number;
	//var CO2Emissions:Number;
	//var CH4Emissions:Number;
	//var N2OEmissions:Number;
	var GHGEmissions:Number;
	var weightedResults:Number;
	//parameters variables:
	var correlation:Number;
	var initYear:Number;
	var initValue:Number;
	var growthRate:Number;
	var stock2005:Number;
	var stock2010:Number;
	var stock2015:Number;
	var stock2020:Number;
	var stock2025:Number;
	var stock2030:Number;

	//The index of this Pathway_mc object in the pathwaysArray belonging to the parent Pathways_Selection_Area clip
	/*  A constructor that creates and properly initializes this object (sets up event handlers for components of the corresponding Pathways_mc MovieClip)
	Arguments: pathwayMC:String - the libary name of the Pathway_mc MovieClip object corresponding to this object
	parent:MovieClip - the Pathways_Selection_Area clip containing this object
	xml:XML - the XML file containing WtW pathways results data
	i:Number - the index of this Pathway_mc object in the pathwaysArray belonging to the parent Pathways_Selection_Area clip
	instNum:Number - the number to use to create a unique instance name for the corresponding Pathways_mc movie clip
	colorsArray:Array - an array containing hex formatted numbers representing possible colors to chose from
	*/
	function PathwayObj(libraryName:String, parent:MovieClip, xml:XML, i:Number, instNum:Number, colors:Array) {
		this.pathwaysSelectionArea = parent;
		this.pathwaysXML = xml;
		this.colorsArray = colors;
		//Create and attach Pathway_mc object to the parent MovieClip:
		this.pathwayMC = pathwaysSelectionArea.attachMovie(libraryName, "pathway"+instNum, pathwaysSelectionArea.getNextHighestDepth());
		
		setIndex(i);
		setTitle("Unspecified Pathway");
		pathwayMC.title_bar.color_picker.colors = colorsArray;
		pathwayMC.title_bar.color_picker.pathwayObj = this;
		pathwayMC.title_bar.color_picker.selectedColor = 0xFFFFFF;
		pathwayMC.title_bar.color_picker.selected_color_box.color = 0xFFFFFF;
		with(pathwayMC.title_bar.color_picker.selected_color_box){
			//lineStyle(0, 0x000000, 0);
			beginFill(color);
			lineTo(0, 9.5);
			lineTo(9.5, 9.5)
			lineTo(9.5, 0);
			lineTo(0, 0);
			endFill();
		} //end with
//trace("(PathwayObj.constructor.70) Initializing areas...");
		//Initialize Pathway area:
		pathwayMC.pathway_area._collapsed = false;
		with(pathwayMC.pathway_area){
			bar._descrTxt = "Pathway";
			bar._collapsableArea = area;
			//_collapsed = false;
//trace("(PathwayObj.constructor.76) ... " + this.abbrev + "  pathway_area._collapsed = " + _collapsed);
			area.vehicle_cb.text = "Please select a vehicle type";
			area.fuel_cb.text = "Please select a vehicle type";
			area.pathway_cb.text = "Please select a vehicle type";
			area._expandedHeight = area._height;
			bar.area.lineStyle(0, 0x000000, 100);
			bar.area.beginFill(0x66CCFF, 100);
			bar.area.lineTo(0, 15.1);
			bar.area.lineTo(232, 15.1)
			bar.area.lineTo(232, 0);
			bar.area.lineTo(0, 0);
			endFill();
			area.petrol_results_txt.backgroundColor = 0xCCCCCC;
			area.fossil_results_txt.backgroundColor = 0xCCCCCC;
			area.other_results_txt.backgroundColor = 0xCCCCCC;
			area.GHG_results_txt.backgroundColor = 0xCCCCCC;
			area.weighted_results_txt.backgroundColor = 0xCCCCCC;
		}  //end with
		pathwayMC.pathway_area.area.petrol_results_txt.text = "";				//.petrolEnergy = "";
		pathwayMC.pathway_area.area.fossil_results_txt.text = "";				//.fossilEnergy = "";
		pathwayMC.pathway_area.area.other_results_txt.text = "";					//.otherEnergy = "";
		//pathwayMC.pathway_area.CO2Emissions = "";
		//pathwayMC.pathway_area.CH4Emissions = "";
		//pathwayMC.pathway_area.N2OEmissions = "";
		pathwayMC.pathway_area.area.GHG_results_txt.text = "";					//.GHGEmissions = "";
		pathwayMC.pathway_area.area.weighted_results_txt.text = "";				//.weightedResults = "";
//trace("  Dimensions: "+pathwayMC.pathway_area.area._width+"x"+pathwayMC.pathway_area.area._height + "(" + pathwayMC.pathway_area.area._expandedHeight + ")");
		//Initialize Parameters area;
		pathwayMC.parameters_area._collapsed = false;
		with(pathwayMC.parameters_area){
			bar._descrTxt = "Model Parameters";
			bar._collapsableArea = area;
			//_collapsed = false;
//trace("(PathwayObj.constructor.100) ... " + this.abbrev + "  parameters_area._collapsed = " + _collapsed);
			area._expandedHeight = area._height;
			bar.area.lineStyle(0, 0x000000, 100);
			bar.area.beginFill(0x66CCFF, 100);
			bar.area.lineTo(0, 15.1);
			bar.area.lineTo(232, 15.1)
			bar.area.lineTo(232, 0);
			bar.area.lineTo(0, 0);
			endFill();
		} //end with
		if(_index == 0){
			pathwayMC.parameters_area.area.correlation.text = "1";
		}
//trace("(PathwayObj.constructor.110) Set up areas... " + this.abbrev + "  (" + this.pathwayMC.pathway_area._collapsed + " , " + this.pathwayMC.parameters_area._collapsed + ")");	
		//Load data from XML file into vehicles combo box
		var vehiclesArray = pathwaysXML.firstChild.childNodes;
//trace("XML: "+pathwaysXML.firstChild.firstChild.firstChild.firstChild.nodeValue);
//trace("loading vehicles combo box entries...");
		vehiclesList = new Array(vehiclesArray.length);
		for (var i = 0; i<vehiclesArray.length; i++) {
			vehiclesList[i] = {data:String(vehiclesArray[i].firstChild.firstChild.nodeValue), label:String(vehiclesArray[i].firstChild.firstChild.nodeValue)};
//trace("   adding: " + vehiclesList[i].label);
		} //end for
		pathwayMC.pathway_area.area.vehicle_cb.listItems = vehiclesList;
//trace("First entry: " + pathwayMC.pathway_area.area.vehicle_cb.getItemAt(0).label + " (" + vehiclesList[0].label + ")");//vehiclesList[0].label + ")");
		
		
		//setup event handlers:
		var owner:PathwayObj = this;
		pathwayMC.title_bar.area.onPress = function() {
			owner.startDragEvent();
		};
		pathwayMC.title_bar.area.onRollOver = function() {
			owner.titleBarRollOverEvent();
		};
		pathwayMC.title_bar.area.onRollOut = function() {
			owner.titleBarRollOutEvent();
		};
		pathwayMC.title_bar.color_picker.bounding_box.onPress = function(){
			owner.colorPickerClickEvent();
		};
		pathwayMC.title_bar.close_button.onRelease = function(){
			owner.closeEvent();
		};
		pathwayMC.pathway_area.bar.onPress = function(){
			owner.expandContractEvent(owner.pathwayMC.pathway_area);
		};
//lock the collapsable area:
//lock(pathwayMC.pathway_area, "_collapsed");
		pathwayMC.pathway_area.bar.onRollOver = function(){
			owner.rollOverBarEvent(owner.pathwayMC.pathway_area.bar);
		};
		pathwayMC.pathway_area.bar.onRollOut = function(){
			owner.rollOutBarEvent(owner.pathwayMC.pathway_area.bar);
		};
		pathwayMC.pathway_area.area.vehicle_cb.changeEventHandler = function(){
			owner.vehicleCBChangeEvent();
		};
		pathwayMC.pathway_area.area.fuel_cb.changeEventHandler = function(){
			owner.fuelCBChangeEvent();
		};
		pathwayMC.pathway_area.area.pathway_cb.changeEventHandler = function(){
			owner.pathwayCBChangeEvent();
		};
		pathwayMC.parameters_area.bar.onPress = function(){
			owner.expandContractEvent(owner.pathwayMC.parameters_area);
		};
//lock the collapsable area:
//lock(pathwayMC.parameters_area, "_collapsed");
		pathwayMC.parameters_area.bar.onRollOver = function(){
			owner.rollOverBarEvent(owner.pathwayMC.parameters_area.bar);
		};
		pathwayMC.parameters_area.bar.onRollOut = function(){
			owner.rollOutBarEvent(owner.pathwayMC.parameters_area.bar);
		};
		/* These event handlers set up in setIndex() function...
		pathwayMC.parameters_area.area.manual_input_checkbox.onRelease = function() {
			owner.checkBoxClickEvent();
		};
		pathwayMC.parameters_area.area.manual_input_checkbox.onRollOver = function() {
			owner.checkBoxRollOverEvent();
		};
		pathwayMC.parameters_area.area.manual_input_checkbox.onRollOut = function() {
			owner.checkBoxRollOutEvent();
		};
		*/
		pathwayMC.parameters_area.area.set_inputs_button.onRelease = function() {
			owner.setInputsEvent();
		};
		pathwayMC.parameters_area.area.clear_inputs_button.onRelease = function() {
			owner.clearInputsEvent();
		};
		
		if(_index == 0){
			titleBarRollOutEvent()	//forces movie clip to redraw and update text format
		}
//trace("(PathwayObj.constructor.191) End of constructor... " + this.abbrev + " (" + this.pathwayMC.pathway_area._collapsed + " , " + this.pathwayMC.parameters_area._collapsed + ")\n");
	}	//end constructor
	

	
/* Functions */
	
	function loadFromSavedPathway(savedPathway:SavedPathwayObj){
		//load and set title and abbreviation:
		this.abbrev = savedPathway.abbrev;
		setTitle(this.abbrev);
//trace("(PathwayObj.loadFromSavedPathway.202)  Before set up collapsable areas... " + this.abbrev + " pathway_area._collapsed? " + this.pathwayMC.pathway_area._collapsed + " - parameters_area._collapsed? " + this.pathwayMC.parameters_area._collapsed);

		//set up collapsable areas:
		if(savedPathway.pathwayIsCollapsed){
			expandContractEvent(this.pathwayMC.pathway_area);
		}
		if(savedPathway.parametersIsCollapsed){
			expandContractEvent(this.pathwayMC.parameters_area);
		}
//trace("(PathwayObj.loadFromSavedPathway.210)  After set up collapsable areas " + this.abbrev + " pathway_area._collapsed? " + this.pathwayMC.pathway_area._collapsed + " - parameters_area._collapsed? " + this.pathwayMC.parameters_area._collapsed);
		
		//load and set up color:
		this.setColor(savedPathway.color);
		
		//load and set combo boxes:
		if(savedPathway.vehiclesListSelectedIndex != undefined){
			this.pathwayMC.pathway_area.area.vehicle_cb.list_box.selectedIndex = savedPathway.vehiclesListSelectedIndex;
			this.pathwayMC.pathway_area.area.vehicle_cb.value = this.pathwayMC.pathway_area.area.vehicle_cb.listItems[savedPathway.vehiclesListSelectedIndex];
			this.pathwayMC.pathway_area.area.vehicle_cb.text = this.pathwayMC.pathway_area.area.vehicle_cb.value.label;
			this.pathwayMC.pathway_area.area.vehicle_cb.selectedIndex = this.pathwayMC.pathway_area.area.vehicle_cb.list_box.selectedIndex;
			vehicleCBChangeEvent();
		}
		if(savedPathway.fuelsListSelectedIndex != undefined){
			this.pathwayMC.pathway_area.area.fuel_cb.list_box.selectedIndex = savedPathway.fuelsListSelectedIndex;
			this.pathwayMC.pathway_area.area.fuel_cb.value = this.pathwayMC.pathway_area.area.fuel_cb.listItems[savedPathway.fuelsListSelectedIndex];
			this.pathwayMC.pathway_area.area.fuel_cb.text = this.pathwayMC.pathway_area.area.fuel_cb.value.label;
			this.pathwayMC.pathway_area.area.fuel_cb.selectedIndex = this.pathwayMC.pathway_area.area.fuel_cb.list_box.selectedIndex;
			fuelCBChangeEvent();
		}
		if(savedPathway.pathwaysListSelectedIndex != undefined){
			this.pathwayMC.pathway_area.area.pathway_cb.list_box.selectedIndex = savedPathway.pathwaysListSelectedIndex;
			this.pathwayMC.pathway_area.area.pathway_cb.value = this.pathwayMC.pathway_area.area.pathway_cb.listItems[savedPathway.pathwaysListSelectedIndex];
			this.pathwayMC.pathway_area.area.pathway_cb.text = this.pathwayMC.pathway_area.area.pathway_cb.value.label;
			this.pathwayMC.pathway_area.area.pathway_cb.selectedIndex = this.pathwayMC.pathway_area.area.pathway_cb.list_box.selectedIndex;
			pathwayCBChangeEvent();
		}
			
trace("(PathwayObj.loadFromSavedPathway.234)  Loaded and setup combo boxes... PetrolEnergy = " + petrolEnergy + " (" + pathwayMC.pathway_area.petrolEnergy + ")");
trace("(PathwayObj.loadFromSavedPathway.235)  Setting up paramaters area check box"); 		
		if(this._index != 0){	//baseline pathway doesn't need to worry about check boxes since user can't input pathway stock variables.
			this.pathwayMC.parameters_area.area.manual_input_checkbox.isChecked = savedPathway.isChecked;
			if(this.pathwayMC.parameters_area.area.manual_input_checkbox.isChecked){
				this.pathwayMC.parameters_area.area.manual_input_checkbox.gotoAndStop(3);
				setManual();
			} else{
				this.pathwayMC.parameters_area.area.manual_input_checkbox.gotoAndStop(1);
				setExpo();
			}
			displayRelative = savedPathway.displayRelative;
			pathwayMC.pathway_area.area.display_relative_checkbox.isChecked = displayRelative;
			if (pathwayMC.pathway_area.area.display_relative_checkbox.isChecked) {
				setRelative();
				pathwayMC.pathway_area.area.display_relative_checkbox.gotoAndStop(3);
			} else{
				setAbsolute();
				pathwayMC.pathway_area.area.display_relative_checkbox.gotoAndStop(1);
			}
		}
		this.pathwayMC.parameters_area.correlationInput = savedPathway.correlationInput;
		this.pathwayMC.parameters_area.initYearInput = savedPathway.initYearInput;
		this.pathwayMC.parameters_area.initValueInput = savedPathway.initValueInput;
		this.pathwayMC.parameters_area.growthRateInput = savedPathway.growthRateInput;
		this.pathwayMC.parameters_area.area.stock_2005.text = savedPathway.stock2005Input;
		this.pathwayMC.parameters_area.area.stock_2010.text = savedPathway.stock2010Input;
		this.pathwayMC.parameters_area.area.stock_2015.text = savedPathway.stock2015Input;
		this.pathwayMC.parameters_area.area.stock_2020.text = savedPathway.stock2020Input;
		this.pathwayMC.parameters_area.area.stock_2025.text = savedPathway.stock2025Input;
		this.pathwayMC.parameters_area.area.stock_2030.text = savedPathway.stock2030Input;
		setInputsEvent();
		
		//Flash changes these variables after the scenario is done loading.  Need to lock them all to prevent the first attempt to change the variables.
		//These variables will unlock after the first attempt to change them is foiled.
		lockOnce(pathwayMC.parameters_area, "_collapsed");
		lockOnce(pathwayMC.parameters_area, "correlationInput");
		lockOnce(pathwayMC.parameters_area, "initYearInput");
		lockOnce(pathwayMC.parameters_area, "initValueInput");
		lockOnce(pathwayMC.parameters_area, "growthRateInput");
		lockOnce(pathwayMC.parameters_area, "stock2005Input");
		lockOnce(pathwayMC.parameters_area, "stock2010Input");
		lockOnce(pathwayMC.parameters_area, "stock2015Input");
		lockOnce(pathwayMC.parameters_area, "stock2020Input");
		lockOnce(pathwayMC.parameters_area, "stock2025Input");
		lockOnce(pathwayMC.parameters_area, "stock2030Input");
		lockOnce(pathwayMC.pathway_area, "_collapsed");
		lockOnce(pathwayMC.pathway_area, "petrolEnergy");
		lockOnce(pathwayMC.pathway_area, "fossilEnergy");
		lockOnce(pathwayMC.pathway_area, "otherEnergy");
		lockOnce(pathwayMC.pathway_area, "weightedResults");
		
//trace("(PathwayObj.loadFromSavedPathway.242) End of loadFromSavedPathway... " + this.abbrev + " (" + this.pathwayMC.pathway_area._collapsed + " , " + this.pathwayMC.parameters_area._collapsed + ");  Init Year = " + this.pathwayMC.parameters_area.initYearInput + "; Stock2005 = " + this.pathwayMC.parameters_area.stock2005Input + "\n");	
	}
	
	
	function setTabOrder(){
		var nextTabIndex = pathwaysSelectionArea.firstTabIndex + _index*10; //10 tab-enabled objects in each PathwayMC MovieClip
//trace("next tab index = " + nextTabIndex);
		pathwayMC.parameters_area.area.correlation.tabIndex = nextTabIndex++;
		pathwayMC.parameters_area.area.init_year.tabIndex = nextTabIndex++;
		pathwayMC.parameters_area.area.init_value.tabIndex = nextTabIndex++;
		pathwayMC.parameters_area.area.growth_rate.tabIndex = nextTabIndex++;
		pathwayMC.parameters_area.area.stock_2005.tabIndex = nextTabIndex++;
		pathwayMC.parameters_area.area.stock_2010.tabIndex = nextTabIndex++;
		pathwayMC.parameters_area.area.stock_2015.tabIndex = nextTabIndex++;
		pathwayMC.parameters_area.area.stock_2020.tabIndex = nextTabIndex++;
		pathwayMC.parameters_area.area.stock_2025.tabIndex = nextTabIndex++;
		pathwayMC.parameters_area.area.stock_2030.tabIndex = nextTabIndex++;
//trace("correlation: " + pathwayMC.parameters_area.area.correlation.tabIndex);
//trace("init year: " + pathwayMC.parameters_area.area.init_year.tabIndex + " init value: " + pathwayMC.parameters_area.area.init_value.tabIndex + " growth rate: " + pathwayMC.parameters_area.area.growth_rate.tabIndex);
	}

	/* Takes three inputs - an initial value, I, an initial year, Y, and an annual growth rate, R and returns an array.
	The array has six elements, corresponding to the years 2005, 2010, 2015, 2020, 2025 and 2030.  An element, e, corresponding 
	to a year, y, is calculated such that e = I*(1+R)^(Y-y) if y >= Y.  e = 0 if y <= Y. */
	function calculateYearValues(initYearInput:String, initValueInput:String, growthRateInput:String):Array {
		initYear = Number(stripCommas(initYearInput));
		initValue = Number(stripCommas(initValueInput));
		growthRate = Number(stripCommas(growthRateInput))/100;
		// <- convert growth rate from percentage to decimal value
	//trace(initYear+" - "+initValue+" - "+growthRate+" ...");
		var toReturn:Array = new Array(6);
		for (var i:Number = 0; i<toReturn.length; i++) {
			var currentYear:Number = 2005+i*5;
			if (currentYear>=initYear) {
				toReturn[i] = new Number(initValue*Math.pow(1+growthRate, currentYear-initYear));
				if(toReturn[i] > Number.MAX_VALUE){  toReturn[i] = Number.MAX_VALUE;  }
				if(toReturn[i] < Number.MIN_VALUE){  toReturn[i] = Number.MIN_VALUE;  }
			} else {
				toReturn[i] = 0;
			}
	//trace("  ... "+currentYear+" -> + "+toReturn[i]);
		}
		return toReturn;
	}
	
	/* Removes all commas from an input String (in preperation for conversion to a Number) */
	function stripCommas(stringIn:String):String {
		var toReturn:String = stringIn;
		while (toReturn.indexOf(",")>=0) {
			//trace("Index of ',': " + toReturn.indexOf(",") + " -> " + toReturn.substring(0, toReturn.indexOf(",")) + " + " + toReturn.substring(toReturn.indexOf(",") + 1));
			toReturn = toReturn.substring(0, toReturn.indexOf(","))+toReturn.substring(toReturn.indexOf(",")+1);
		}
		return toReturn;
	}
	
	/* Formats a String containing a number with commas in the thousands places and up to 2 decimal places (if any).
	Returns the correctly formatted string.  Only correctly formats numbers < 1 billion. (larger numbers will be rounded 
	to two decimals but won't insert commas*/
	function formatNumber(number:String):String {
		var toReturn:String;
		var decimals:String;
		//Round decimal places to up to 2 (if any)
		if (number.indexOf(".")>=0) {
			toReturn = number.substring(0, number.indexOf("."));
			//strip off decimal digits for now
			decimals = number.substring(number.indexOf(".")+1);
			//round to 2 decimal places:
			while (decimals.length>2) {
				var current_digit:Number = Number(decimals.substr(-1));
				var next_digit:Number = Number(decimals.substr(-2, 1));
				if (current_digit>=5) {
					next_digit++;
				}
				decimals = decimals.substr(0, decimals.length-2)+next_digit;
			}
		} else {
			toReturn = number;
		}
		//insert commas in thousands places:
		var num:Number = Number(toReturn);
		if (num>=1000000 && num<1000000000) {
			toReturn = toReturn.substr(0, toReturn.length-6)+","+toReturn.substr(toReturn.length-6, 3)+","+toReturn.substr(toReturn.length-3);
		} else if (num>=1000 && num<1000000) {
			toReturn = toReturn.substr(0, toReturn.length-3)+","+toReturn.substr(toReturn.length-3);
		} else {
			//leave string alone
		}
		if (number.indexOf(".")>=0) {
			toReturn = toReturn+"."+decimals;
		}
		return toReturn;
	}
	
	/*  EVENT HANDLERS */

	function closeEvent() {
//trace("removing....");
		pathwaysSelectionArea.removePathway(_index);
	} //end closeEvent
	
	function startDragEvent(){
		//create drag box:
		dragBoxMC = pathwaysSelectionArea.createEmptyMovieClip("dragBox", pathwaysSelectionArea.getNextHighestDepth());
		dragBoxMC.moveTo(pathwayMC._x, 0);
		dragBoxMC.lineStyle(1, 0x00FFFF, 65);
		dragBoxMC.beginFill(0xFFFFFF, 35);
		dragBoxMC.lineTo(pathwayMC._x + pathwayMC._width, 0);	
//trace("  drawing from (" + pathwayMC._x + ",0") to (" + (pathwayMC._x + pathwayMC._width) + ",0")"); 
		dragBoxMC.lineTo(pathwayMC._x + pathwayMC._width, pathwayMC._height);
//trace("  drawing from (" + (pathwayMC._x + pathwayMC._width) + ",0") to (" + (pathwayMC._x + pathwayMC._width) + "," + pathwayMC._height)); 
		dragBoxMC.lineTo(pathwayMC._x, pathwayMC._height);
//trace("  drawing from ("+ (pathwayMC._x + pathwayMC._width) + "," + pathwayMC._height + ") to (" + (pathwayMC._x) + "," + pathwayMC._height));
		dragBoxMC.lineTo(pathwayMC._x, 0);
//trace("  drawing from ("+ (pathwayMC._x) + "," +  pathwayMC._height) + ") to (" + (pathwayMC._x) + ",0");
		dragBoxMC.endFill();
//trace("  Creating drag box: " + dragBoxMC._width + "x" + dragBoxMC._height + " at y = " + dragBoxMC._y);
		dragBoxMC._y = pathwayMC._y;
//trace("  ... and moving to y = " + dragBoxMC._y + "(" + pathwayMC._y + ")");
		//create and register listeners:
		var endDragEventListener:Object = new Object();
		var mouseDragEventListener:Object = new Object();
		var owner:PathwayObj = this;
		endDragEventListener.onMouseUp = function(){
			owner.endDragEvent(endDragEventListener, mouseDragEventListener);
		};
		mouseDragEventListener.onMouseMove = function(){
			owner.mouseDragEvent();
		};
		Mouse.addListener(endDragEventListener);
		Mouse.addListener(mouseDragEventListener);
	}
	
	/* 
	Parameters: endDragEventListener:Object - a listener that has been used throughout this drag event and will now be removed
	mouseDragEventListener:Object - a that has been used throughout this drag event and will now be removed
	*/
	function endDragEvent(endDragEventListener:Object, mouseDragEventListener:Object){
//trace("  drag ending ... destroying drag box");
		dragBoxMC.removeMovieClip();
		Mouse.removeListener(endDragEventListener);
		Mouse.removeListener(mouseDragEventListener);
		pathwaysSelectionArea.reorderPathways(pathwaysSelectionArea._ymouse, _index);
	}
	
	function mouseDragEvent(){
		 dragBoxMC._y = pathwaysSelectionArea._ymouse;  
		// trace("...moving to: " + boxMC._y + " (" + area._ymouse + "-" + owner.pathwayMC._y + ")");
	}
	
	function titleBarRollOverEvent(){
		var my_fmt:TextFormat = new TextFormat;
		my_fmt.bold = true;
		pathwayMC.title_bar.txt.descr.setTextFormat(my_fmt);
	} //end titleBarRollOverEvent
	
	function titleBarRollOutEvent(){
		var my_fmt:TextFormat = new TextFormat;
		my_fmt.bold = false;
		pathwayMC.title_bar.txt.descr.setTextFormat(my_fmt);
	} //end titleBarRollOutEvent
	
	function colorPickerClickEvent(){
	 	pathwayMC.title_bar.color_picker.nextFrame();
	}
	
	function startColorPicker(){
		previousDepth = pathwayMC.getDepth();
		pathwayMC.swapDepths(10000);			//'pop' pathwayMC to top depth, to ensure that color picker area is in front
//trace("Popping depth from " + previousDepth + " to " + pathwayMC.getDepth());
	}
	
	function endColorPicker(){
		pathwayMC.swapDepths(previousDepth);	//put pathwayMC back at old depth
//trace("returning depth to " + previousDepth + " (" + pathwayMC.getDepth() + ")");
	}
	

	
	function expandContractEvent(area:MovieClip){
//unlock collapsable area:
//unlock(area, "_collapsed");
		
//trace("(PathwayObj.expandContractEvent.417) Beginning of expandContractEvent:  " + this.abbrev + " pathway_area._collapsed? " + this.pathwayMC.pathway_area._collapsed + " - parameters_area._collapsed? " + this.pathwayMC.parameters_area._collapsed +"\n");
			if (area._collapsed) {
//trace("...expanding collapsable area");
				area.bar.arrow_icon.gotoAndPlay(1);
				with(area.bar.area){
					lineStyle(0, 0x000000, 100);
					beginFill(0x66CCFF, 100);
					lineTo(0, 15.1);
					lineTo(232, 15.1)
					lineTo(232, 0);
					lineTo(0, 0);
					endFill();
				} //end with
				area.bar._collapsableArea._height = area.bar._collapsableArea._expandedHeight;
//trace("Expanding to "+pathwayMC.pathway_area.bar._collapsableArea._height + " (" + pathwayMC._height + ")");
				area._collapsed = false;
			} else {
//trace("...collapsing collapsable area");
				area.bar.arrow_icon.gotoAndPlay(2);
				with(area.bar.area){
					lineStyle(0, 0x000000, 100);
					beginFill(0xCCCCCC ,100);
					lineTo(0, 15.1);
					lineTo(232, 15.1)
					lineTo(232, 0);
					lineTo(0, 0);
					endFill();
				} //end with
				area.bar._collapsableArea._height = 0;
//trace("Contracting to " + pathwayMC.pathway_area.bar._collapsableArea._height);
				area._collapsed = true;
			}
			pathwayMC.parameters_area._y = pathwayMC.pathway_area._y + pathwayMC.pathway_area._height;
			pathwaysSelectionArea.drawPathways(_index);
//trace("(PathwayObj.expandContractEvent.449) End of expandContractEvent: " + this.abbrev + " pathway_area._collapsed? " + this.pathwayMC.pathway_area._collapsed + " - parameters_area._collapsed? " + this.pathwayMC.parameters_area._collapsed +"\n");
		
//relock the collapsable area:
//lock(area, "_collapsed");

	}  //end expandContractEvent
	
	function rollOverBarEvent(bar:MovieClip){
		//trace("over...");
		var my_fmt:TextFormat = new TextFormat();
		my_fmt.bold = true;
		bar.txt.descr.setTextFormat(my_fmt);
	}  //end rollOverBarEvent
	
	function rollOutBarEvent(bar:MovieClip){
//trace("...out");
		var my_fmt:TextFormat = new TextFormat();
		my_fmt.bold = false;
		bar.txt.descr.setTextFormat(my_fmt);		
	}  //end rollOutBarEvent
	
	function vehicleCBChangeEvent(){
		var vehCB = this.pathwayMC.pathway_area.area.vehicle_cb;
//var selectedVehicle:String = vehCB.value.label;
//trace("Vehicle selected: " + selectedVehicle);
		
		var vehiclesArray:Array = this.pathwaysXML.firstChild.childNodes;
		var fuelsArray:Array = vehiclesArray[vehCB.selectedIndex].childNodes;
		fuelsList = new Array(fuelsArray.length - 1);
		for (var i = 1; i<fuelsArray.length; i++) {		//start at index = 1, first child node is the description node; skip it
			fuelsList[i-1] = {data:String(fuelsArray[i].firstChild.firstChild.nodeValue), label:String(fuelsArray[i].firstChild.firstChild.nodeValue)};
//trace("   adding: " + fuelsList[i-1].label);
		} //end for
		pathwayMC.pathway_area.area.fuel_cb.listItems = fuelsList;
		pathwayMC.pathway_area.area.fuel_cb.text = "Please select a fuel";
		pathwayMC.pathway_area.area.pathway_cb.text = "Please select a fuel";
		
		this.petrolEnergy = undefined;
		this.fossilEnergy = undefined;
		this.otherEnergy = undefined;
		//this.CO2Emissions = undefined;
		//this.CH4Emissions = undefined;
		//this.N2OEmissions = undefined;
		this.GHGEmissions = undefined;
		
		pathwayMC.pathway_area.area.petrol_results_txt.text = "";				//.petrolEnergy = "";
		pathwayMC.pathway_area.area.fossil_results_txt.text = "";				//.fossilEnergy = "";
		pathwayMC.pathway_area.area.other_results_txt.text = "";					//.otherEnergy = "";
		//pathwayMC.pathway_area.CO2Emissions = "";
		//pathwayMC.pathway_area.CH4Emissions = "";
		//pathwayMC.pathway_area.N2OEmissions = "";
		pathwayMC.pathway_area.area.GHG_results_txt.text = "";					//.GHGEmissions = "";
		pathwayMC.pathway_area.area.weighted_results_txt.text = "";				//.weightedResults = "";
		
		this.pathwaysSelectionArea.drawCurrentGraphOrChart();
	}  //end vehicleCBChangeEvent
	
	function fuelCBChangeEvent(){
		var vehCB = this.pathwayMC.pathway_area.area.vehicle_cb;
		var fuelCB = this.pathwayMC.pathway_area.area.fuel_cb;
		//var selectedFuel:String = fuelCB.value.label;
//trace("Fuel selected: " + selectedFuel);
		
		var vehiclesArray = this.pathwaysXML.firstChild.childNodes;
		var fuelsArray = vehiclesArray[vehCB.selectedIndex].childNodes;
		var pathwaysArray = fuelsArray[fuelCB.selectedIndex + 1].childNodes;	//add one to makeup for fact that we skipped vehicle node's description node (see vehicleCBChangeEvent above)		
		pathwaysList = new Array(pathwaysArray.length - 1);
		for (var i = 1; i<pathwaysArray.length; i++) {		//start at index = 1, first child node is the description node; skip it
			pathwaysList[i-1] = {data:String(pathwaysArray[i].firstChild.firstChild.nodeValue), label:String(pathwaysArray[i].firstChild.firstChild.nodeValue)};
//trace("   adding: " + pathwaysList[i-1].label);
		} //end for
		pathwayMC.pathway_area.area.pathway_cb.listItems = pathwaysList;
		pathwayMC.pathway_area.area.pathway_cb.text = "Please select a pathway";
		
		this.petrolEnergy = undefined;
		this.fossilEnergy = undefined;
		this.otherEnergy = undefined;
		//this.CO2Emissions = undefined;
		//this.CH4Emissions = undefined;
		//this.N2OEmissions = undefined;
		this.GHGEmissions = undefined;
		
		pathwayMC.pathway_area.area.petrol_results_txt.text = "";				//.petrolEnergy = "";
		pathwayMC.pathway_area.area.fossil_results_txt.text = "";				//.fossilEnergy = "";
		pathwayMC.pathway_area.area.other_results_txt.text = "";					//.otherEnergy = "";
		//pathwayMC.pathway_area.CO2Emissions = "";
		//pathwayMC.pathway_area.CH4Emissions = "";
		//pathwayMC.pathway_area.N2OEmissions = "";
		pathwayMC.pathway_area.area.GHG_results_txt.text = "";					//.GHGEmissions = "";
		pathwayMC.pathway_area.area.weighted_results_txt.text = "";				//.weightedResults = "";
		
		this.pathwaysSelectionArea.drawCurrentGraphOrChart();
	}  //end fuelCBChangeEvent
	
	function pathwayCBChangeEvent(){
		var vehCB = this.pathwayMC.pathway_area.area.vehicle_cb;
		var fuelCB = this.pathwayMC.pathway_area.area.fuel_cb;
		var pathwayCB = this.pathwayMC.pathway_area.area.pathway_cb;
		var selectedPathway:String = pathwayCB.value.label;
//trace("Pathway selected: " + selectedPathway);
		
		var vehiclesArray:Array = this.pathwaysXML.firstChild.childNodes;
		var fuelsArray:Array = vehiclesArray[vehCB.selectedIndex].childNodes;
		var pathwaysArray:Array = fuelsArray[fuelCB.selectedIndex + 1].childNodes;	//add one to makeup for fact that we skipped vehicle node's description node (see vehicleCBChangeEvent above)		
		var childNodes:Array = pathwaysArray[pathwayCB.selectedIndex + 1].childNodes;  // ditto above line
		this.abbrev = childNodes[1].firstChild.nodeValue;
		this.setTitle(abbrev);
		
		var resultsArray:Array = childNodes[2].childNodes;
		
		var total:Number = Number(resultsArray[0].firstChild.nodeValue);
		var fossil:Number = Number(resultsArray[1].firstChild.nodeValue);
		this.petrolEnergy = Number(resultsArray[2].firstChild.nodeValue);
		this.fossilEnergy = fossil-petrolEnergy;
		this.otherEnergy = total-fossil;
		//this.CO2Emissions = Number(resultsArray[3].firstChild.nodeValue);
		//this.CH4Emissions = Number(resultsArray[4].firstChild.nodeValue);
		//this.N2OEmissions = Number(resultsArray[5].firstChild.nodeValue);
		this.GHGEmissions = Number(resultsArray[6].firstChild.nodeValue);
//trace("(PathwayObj.pathwayCBChangeEvent.569)   Calling updateWtWResults()");
		this.pathwaysSelectionArea.updateWtWResults();
		this.pathwaysSelectionArea.drawCurrentGraphOrChart();
		
		
//trace("Results:\n  Petrol Energy: " + this.petrolEnergy + "\n  Other Fossil Energy: " + this.fossilEnergy + "\n  Other Energy: " + this.otherEnergy + "\n  (Total Energy: " + total + 
//	  			")\n  CO2 emissions: " + this.CO2Emissions + "\n  CH4 emissions: " + 
//	  			this.CH4Emissions + "\n  N2O emissions: " + this.N2OEmissions + "\n Total GHG emissions: " + this.GHGEmissions + "\n");
		
	}  //end pathwayCBChangeEvent
	
	
	/* Scales the displayed Well-to-Wheel results for this pathway from the underlying Well-to-Wheels study to 
	/* reflect difference in 2005 baseline fuel economy (as input by user) and the fuel economy assumed by
	/* the underlying Well-to-Wheels study.  
	/* This method is called by the parent pathwaysSelectionArea MovieClip which knows what the user inputs are. 
	/*
	/* (Note: only scales the displayed values, not the results variables for 
    /* this pathway, which remain the same as the underlying WtW study.  These unscaled results values are needed in model calculations later.) */
	function updateWtWResults(mpg2005:Number, mpgWtWStudy:Number){
trace("\n(PathwayObj.updateWtWResults.589)  Updating WtW Results for Pathway " + _index + " (" + mpg2005 + " , " + mpgWtWStudy + ")");
		// Sets the displayed well-to-wheel results for this pathway to display values scaled for 2005 given the baseline fuel economy assumptions input by the user.
		var thisScaled:Number;
		var baselineResult:Number;
		var baselineScaled:Number;
		var percentChange:Number;
		if(this.petrolEnergy != undefined && !isNaN(this.petrolEnergy) && mpg2005 != undefined && !isNaN(mpg2005)){ 
trace("Petrol Energy Results should be: " + formatNumber(String(this.petrolEnergy*(mpgWtWStudy/mpg2005)))); 
			if(displayRelative && this._index != 0){
				thisScaled = this.petrolEnergy*(mpgWtWStudy/mpg2005);
				baselineResult = PathwayObj(pathwaysSelectionArea.pathwaysArray[0]).petrolEnergy;
				if(baselineResult != undefined && !isNaN(baselineResult) && baselineResult != 0){
					baselineScaled = baselineResult*(mpgWtWStudy/mpg2005);
					percentChange = (thisScaled/baselineScaled - 1)*100;
					pathwayMC.pathway_area.area.petrol_results_txt.text = formatNumber(String(percentChange)) + "%";
				}else{
					pathwayMC.pathway_area.area.petrol_results_txt.text = "error";
				}
			}else{
				pathwayMC.pathway_area.area.petrol_results_txt.text = formatNumber(String(this.petrolEnergy*(mpgWtWStudy/mpg2005))); 
			}
		} else {
			pathwayMC.pathway_area.area.petrol_results_txt.text = "";
		}
		if(this.fossilEnergy != undefined && !isNaN(this.fossilEnergy) && mpg2005 != undefined && !isNaN(mpg2005)){ 
			if(displayRelative && this._index != 0){
				thisScaled = this.fossilEnergy*(mpgWtWStudy/mpg2005);
				baselineResult = PathwayObj(pathwaysSelectionArea.pathwaysArray[0]).fossilEnergy;
				if(baselineResult != undefined && !isNaN(baselineResult) && baselineResult != 0){
					baselineScaled = baselineResult*(mpgWtWStudy/mpg2005);
					percentChange = (thisScaled/baselineScaled - 1)*100;
					pathwayMC.pathway_area.area.fossil_results_txt.text = formatNumber(String(percentChange)) + "%";
				}else{
					pathwayMC.pathway_area.area.fossil_results_txt.text = "error";
				}
			}else{
				pathwayMC.pathway_area.area.fossil_results_txt.text = formatNumber(String(this.fossilEnergy*(mpgWtWStudy/mpg2005))); 
			}
		} else {
			pathwayMC.pathway_area.area.fossil_results_txt.text = "";
		}
		if(this.otherEnergy != undefined && !isNaN(this.otherEnergy) && mpg2005 != undefined && !isNaN(mpg2005)){ 
			if(displayRelative && this._index != 0){
				thisScaled = this.otherEnergy*(mpgWtWStudy/mpg2005);
				baselineResult = PathwayObj(pathwaysSelectionArea.pathwaysArray[0]).otherEnergy;
				if(baselineResult != undefined && !isNaN(baselineResult) && baselineResult != 0){
					baselineScaled = baselineResult*(mpgWtWStudy/mpg2005);
					percentChange = (thisScaled/baselineScaled - 1)*100;
					pathwayMC.pathway_area.area.other_results_txt.text = formatNumber(String(percentChange)) + "%";
				}else{
					pathwayMC.pathway_area.area.other_results_txt.text = "error";
				}
			}else{
				pathwayMC.pathway_area.area.other_results_txt.text = formatNumber(String(this.otherEnergy*(mpgWtWStudy/mpg2005))); 
			}
		} else {
			pathwayMC.pathway_area.area.other_results_txt.text = "";
		}
 		/*if(this.CO2Emissions != undefined && !isNaN(this.CO2Emissions) && mpg2005 != undefined && !isNaN(mpg2005)){ 
			pathwayMC.pathway_area.CO2Emissions = formatNumber(String(this.CO2Emissions*(mpgWtWStudy/mpg2005))); 
		} else{
			pathwayMC.pathway_area.CO2Emissions = "";
		} 
		if(this.CH4Emissions != undefined && !isNaN(this.CH4Emissions) && mpg2005 != undefined && !isNaN(mpg2005)){ 
			pathwayMC.pathway_area.CH4Emissions = formatNumber(String(this.CH4Emissions*(mpgWtWStudy/mpg2005))); 
		} else {
			pathwayMC.pathway_area.CH4Emissions = "";
		}
		if(this.N2OEmissions != undefined && !isNaN(this.N2OEmissions) && mpg2005 != undefined && !isNaN(mpg2005)){ 
			pathwayMC.pathway_area.N2OEmissions = formatNumber(String(this.N2OEmissions*(mpgWtWStudy/mpg2005))); 
		} else {
			pathwayMC.pathway_area.N2OEmissions = "";
		}*/
		if(this.GHGEmissions != undefined && !isNaN(this.GHGEmissions) && mpg2005 != undefined && !isNaN(mpg2005)){ 
			if(displayRelative && this._index != 0){
				thisScaled = this.GHGEmissions*(mpgWtWStudy/mpg2005);
				baselineResult = PathwayObj(pathwaysSelectionArea.pathwaysArray[0]).GHGEmissions;
				if(baselineResult != undefined && !isNaN(baselineResult) && baselineResult != 0){
					baselineScaled = baselineResult*(mpgWtWStudy/mpg2005);
					percentChange = (thisScaled/baselineScaled - 1)*100;
					pathwayMC.pathway_area.area.GHG_results_txt.text = formatNumber(String(percentChange)) + "%";
				}else{
					pathwayMC.pathway_area.area.GHG_results_txt.text = "error";
				}
			}else{
				pathwayMC.pathway_area.area.GHG_results_txt.text = formatNumber(String(this.GHGEmissions*(mpgWtWStudy/mpg2005))); 
			}
		} else {
			pathwayMC.pathway_area.area.GHG_results_txt.text = "";
		}
trace("petrolEnergy = " + pathwayMC.pathway_area.area.petrol_results_txt.text + "; fossilEnergy = " + pathwayMC.pathway_area.area.fossil_results_txt.text + "; otherEnergy = " + pathwayMC.pathway_area.area.other_results_txt.text + " GHGEmissions = " + pathwayMC.pathway_area.area.GHG_results_txt.text + " mpg2005 = " + mpg2005);
		updateWeightedResults();	//update weighted results now that well-to-wheel results are scaled properly.
	}
	
	
	
	function updateWeightedResults(){
//trace("\n update weighted results: normalized? " + this.pathwaysSelectionArea.isNormalized + ", relative? " + this.pathwaysSelectionArea.isRelativeChange);
trace("Updating weighted results: Pathway = " + this.abbrev + " petrolWeight = " + this.pathwaysSelectionArea.petrolEnergyWeight + " fossilWeight = " + this.pathwaysSelectionArea.fossilEnergyWeight +
	  	" otherWeight = " + this.pathwaysSelectionArea.otherEnergyWeight + " GHGWeight = " + this.pathwaysSelectionArea.GHGEmissionsWeight);
		if(this.pathwaysSelectionArea.petrolEnergyWeight != undefined && !isNaN(this.pathwaysSelectionArea.petrolEnergyWeight) &&
				this.pathwaysSelectionArea.fossilEnergyWeight != undefined && !isNaN(this.pathwaysSelectionArea.fossilEnergyWeight) &&
				this.pathwaysSelectionArea.otherEnergyWeight != undefined && !isNaN(this.pathwaysSelectionArea.otherEnergyWeight) &&
				this.pathwaysSelectionArea.GHGEmissionsWeight != undefined && !isNaN(this.pathwaysSelectionArea.GHGEmissionsWeight)){
				
			if(this.pathwaysSelectionArea.isNormalized){
				//normalizes values to the same order of magnitude (i.e. the same power of 10).  Assumes energy results are in the thousands and GHG emissions are in the hundreds. 
				this.weightedResults = this.petrolEnergy*this.pathwaysSelectionArea.petrolEnergyWeight/1000 + this.fossilEnergy*this.pathwaysSelectionArea.fossilEnergyWeight/1000 +
									this.otherEnergy*this.pathwaysSelectionArea.otherEnergyWeight/1000 + this.GHGEmissions*this.pathwaysSelectionArea.GHGEmissionsWeight/100;
			} else{
				this.weightedResults = this.petrolEnergy*this.pathwaysSelectionArea.petrolEnergyWeight + this.fossilEnergy*this.pathwaysSelectionArea.fossilEnergyWeight +
									this.otherEnergy*this.pathwaysSelectionArea.otherEnergyWeight + this.GHGEmissions*this.pathwaysSelectionArea.GHGEmissionsWeight;
			}
			
			if(this.pathwaysSelectionArea.isRelativeChange){
				if(this._index == 0){
					this.pathwaysSelectionArea.baselineWeightedResults = this.weightedResults;
	//trace("Setting baselineWeightedResults = " + this.pathwaysSelectionArea.baselineWeightedResults + " (" + this.weightedResults + ")");
					this.weightedResults = 100;
				} else{
	//trace("baseline pathway = " + this.pathwaysSelectionArea.baselineWeightedResults + " ; this pathway = " + this.weightedResults);
					if(this.pathwaysSelectionArea.baselineWeightedResults == 0){
						this.weightedResults = 0;
					} else{
						this.weightedResults = this.weightedResults/this.pathwaysSelectionArea.baselineWeightedResults*100;
					}
				}
			}
			
			if(this.weightedResults != undefined && !(isNaN(this.weightedResults))){
				if(displayRelative && this._index != 0){
					var baselineResult:Number = PathwayObj(pathwaysSelectionArea.pathwaysArray[0]).weightedResults;
					if(baselineResult != undefined && !isNaN(baselineResult) && baselineResult != 0){
						var percentChange:Number = (this.weightedResults/baselineResult - 1)*100;
						pathwayMC.pathway_area.area.weighted_results_txt.text = formatNumber(String(percentChange)) + "%";
					}else{
						pathwayMC.pathway_area.area.weighted_results_txt.text = "error";
					}
				}else{
					pathwayMC.pathway_area.area.weighted_results_txt.text = formatNumber(String(this.weightedResults));
				}
	trace("\n!Setting Weighted Results: Pathway = " + this.abbrev + " - Weighted Results = " + this.weightedResults + " (" + this.petrolEnergy + " , " + this.fossilEnergy + " , " + this.otherEnergy + " , " + this.GHGEmissions + ")  isRelativeChange? " + this.pathwaysSelectionArea.isRelativeChange + " isNormalized? " + this.pathwaysSelectionArea.isNormalized + "\n");
			}else{
	trace("Error: Pathway = " + this.abbrev + " - Weighted Results = " + this.weightedResults + " (" + this.petrolEnergy + " , " + this.fossilEnergy + " , " + this.otherEnergy + " , " + this.GHGEmissions + ")");
				pathwayMC.pathway_area.area.weighted_results_txt.text = "";
			}
		} else {
			pathwayMC.pathway_area.area.weighted_results_txt.text = "";
		}
	}
	
	
	/*  Check Boxes  */
	function checkBoxClickEvent(checkBox:MovieClip) {
trace("Checked " + checkBox._name + " (" + checkBox.isChecked + ")");
		if (checkBox.isChecked) {
			checkBox.gotoAndPlay("2");
			checkBox.isChecked = false;
			if(checkBox._name == "manual_input_checkbox"){
				pathwayMC.parameters_area.setExpo();
			} else if(checkBox._name == "display_relative_checkbox"){
				setAbsolute();
			}
		} else {
			checkBox.gotoAndPlay("4");
			checkBox.isChecked = true;
			if(checkBox._name == "manual_input_checkbox"){
				pathwayMC.parameters_area.setManual();
			} else if(checkBox._name == "display_relative_checkbox"){
				setRelative();
			}
		}
	}  //end checkBoxClickEvent
	function checkBoxRollOverEvent(checkBox:MovieClip) {
		if (checkBox.isChecked) {
			checkBox.gotoAndPlay("4");
		} else {
			checkBox.gotoAndPlay("2");
		}
	}  //end checkBoxRollOverEvent
	function checkBoxRollOutEvent(checkBox:MovieClip) {
		if (checkBox.isChecked) {
			checkBox.gotoAndPlay("3");
		} else {
			checkBox.gotoAndPlay("1");
		}
	}  //end checkBoxRollOutEvent

	/* Sets all Number values corresponding to input strings.  
	returns a boolean indicating if values were set succesfully.
	Calculates yearly values if not using manual input.
	If errors are encountered, 'false' is returned, else, 'true'. */
	/* NEED TO WRITE ERROR HANDLING */
	function setInputsEvent():Boolean {
		correlation = Number(stripCommas(pathwayMC.parameters_area.correlationInput));
		if(_index != 0){		//if baseline pathway, these parameters are calculated and are not input values
			if (pathwayMC.parameters_area.area.manual_input_checkbox.isChecked) {
trace("(PathwayObj.setInputsEvent.706)  setting inputs (isManual) " + abbrev + " - Correlation = " + pathwayMC.parameters_area.correlationInput + " - stock2005 = " + pathwayMC.parameters_area.area.stock_2005.text);
				stock2005 = Number(stripCommas(pathwayMC.parameters_area.area.stock_2005.text));
				stock2010 = Number(stripCommas(pathwayMC.parameters_area.area.stock_2010.text));
				stock2015 = Number(stripCommas(pathwayMC.parameters_area.area.stock_2015.text));
				stock2020 = Number(stripCommas(pathwayMC.parameters_area.area.stock_2020.text));
				stock2025 = Number(stripCommas(pathwayMC.parameters_area.area.stock_2025.text));
				stock2030 = Number(stripCommas(pathwayMC.parameters_area.area.stock_2030.text));
			} else {
trace("(PathwayObj.setInputsEvent.714)  setting inputs (isExpo)" + abbrev + " - Correlation = " + pathwayMC.parameters_area.correlationInput + " - stock2005 = " + pathwayMC.parameters_area.area.stock_2005.text);
				if(pathwayMC.parameters_area.initYearInput == "" || pathwayMC.parameters_area.initValueInput == "" || pathwayMC.parameters_area.growthRateInput == ""){
					//do nothing, input parameters not correctly set.
					//NOTE: Add error handling message here later.
				} else{
					var tmpArray:Array;
					tmpArray = calculateYearValues(pathwayMC.parameters_area.initYearInput, pathwayMC.parameters_area.initValueInput, pathwayMC.parameters_area.growthRateInput);
					stock2005 = tmpArray[0];
					pathwayMC.parameters_area.area.stock_2005.text = formatNumber(stock2005.toString());
					stock2010 = tmpArray[1];
					pathwayMC.parameters_area.area.stock_2010.text = formatNumber(stock2010.toString());
					stock2015 = tmpArray[2];
					pathwayMC.parameters_area.area.stock_2015.text = formatNumber(stock2015.toString());
					stock2020 = tmpArray[3];
					pathwayMC.parameters_area.area.stock_2020.text = formatNumber(stock2020.toString());
					stock2025 = tmpArray[4];
					pathwayMC.parameters_area.area.stock_2025.text = formatNumber(stock2025.toString());
					stock2030 = tmpArray[5];
					pathwayMC.parameters_area.area.stock_2030.text = formatNumber(stock2030.toString());
				}
trace("(PathwayObj.setInputsEvent.729) .... stock2030Input = " + pathwayMC.parameters_area.area.stock_2030.text);
			}
		} else{
trace("\nSetting Inputs for baseline pathway\n");
		}
		this.pathwaysSelectionArea.drawCurrentGraphOrChart();
		return true;
	}
	
	/* Clears all input values and resets them to empty strings */
	function clearInputsEvent():Void {
		pathwayMC.parameters_area.correlationInput = "";
		pathwayMC.parameters_area.correlation = undefined;
		if(_index != 0){  		//if baseline pathway, these parameters are calculated and are not input values
			with(pathwayMC.parameters_area){
				initYearInput = "";
				initValueInput = "";
				growthRateInput = "";
				area.stock_2005.text = "";
				area.stock_2010.text = "";
				area.stock_2015.text = "";
				area.stock_2020.text = "";
				area.stock_2025.text = "";
				area.stock_2030.text = "";
			} //end with
			stock2005 = undefined;
			stock2010 = undefined;
			stock2015 = undefined;
			stock2020 = undefined;
			stock2025 = undefined;
			stock2030 = undefined;
		}
		this.pathwaysSelectionArea.drawCurrentGraphOrChart();
	}


	//getters and setters:
	function getPathwayMC_y():Number{
		return this.pathwayMC._y;
	}
	function getPathwayMC_x():Number{
		return this.pathwayMC._x;
	}
	function getPathwayMC_height():Number{
		return this.pathwayMC._height;
	}
	function getPathwayMC_width():Number{
		return this.pathwayMC._width;
	}
	function getTitle():String{
		return this.pathwayMC.title_bar._descrTxt;
	}
	function getColor():Number{
		return this.color;
	}
	function getIndex():Number{
		return this._index;
	}
	
	function setPathwayMC_y(Y:Number):Void{
		this.pathwayMC._y = Y;
	}
	function setPathwayMC_x(X:Number):Void{
		this.pathwayMC._x = X;
	}
	function setPathwayMC_height(H:Number):Void{
		this.pathwayMC._height = H;
	}
	function setPathwayMC_width(W:Number):Void{
		this.pathwayMC._width = W;
	}
	function setTitle(t:String):Void{
		this.pathwayMC.title_bar._descrTxt = t;
	}
	function setColor(c:Number):Void{
		this.color = c;
		this.pathwayMC.title_bar.color_picker.selected_color_box.color = c;
		with(this.pathwayMC.title_bar.color_picker.selected_color_box){
			//lineStyle(0, 0x000000, 0);
			beginFill(color);
			lineTo(0, 9.5);
			lineTo(9.5, 9.5)
			lineTo(9.5, 0);
			lineTo(0, 0);
			endFill();
		} //end with
//trace("SETTING COLOR TO: " + this.color + " (" + c + ")");
       this.pathwaysSelectionArea.drawCurrentGraphOrChart();
	}
	function setIndex(n:Number):Void{
		this._index = n;
		var my_fmt:TextFormat = new TextFormat();
		if(this._index == 0){
			// this is the baseline pathway, make title italic to signify:
			my_fmt.italic = true;
			/* 'deactiave'/grey out 'Vehicle Stock' input fields -
			baseline pathway's values are what's left over from total stock after each other pathway is calculated */
			with(pathwayMC.parameters_area){
				area.correlation.type = "dynamic";
				area.correlation.backgroundColor = 0xCCCCCC;
				area.init_year.type = "dynamic";
				area.init_year.backgroundColor = 0xCCCCCC;
				area.init_value.type = "dynamic";
				area.init_value.backgroundColor = 0xCCCCCC;
				area.growth_rate.type = "dynamic";
				area.growth_rate.backgroundColor = 0xCCCCCC;
				area.stock_2005.type = "dynamic";
				area.stock_2005.backgroundColor = 0xCCCCCC;
				area.stock_2010.type = "dynamic";
				area.stock_2010.backgroundColor = 0xCCCCCC;
				area.stock_2015.type = "dynamic";
				area.stock_2015.backgroundColor = 0xCCCCCC;
				area.stock_2020.type = "dynamic";
				area.stock_2020.backgroundColor = 0xCCCCCC;
				area.stock_2025.type = "dynamic";
				area.stock_2025.backgroundColor = 0xCCCCCC;
				area.stock_2030.type = "dynamic";
				area.stock_2030.backgroundColor = 0xCCCCCC;
				area.correlation_input.tabEnabled = false;
				area.init_year.tabEnabled = false;
				area.init_value.tabEnabled = false;
				area.growth_rate.tabEnabled = false;
				area.stock_2005.tabEnabled = false;
				area.stock_2010.tabEnabled = false;
				area.stock_2015.tabEnabled = false;
				area.stock_2020.tabEnabled = false;
				area.stock_2025.tabEnabled = false;
				area.stock_2030.tabEnabled = false;
				area.set_inputs_button.enabled = false;
				area.clear_inputs_button.enabled = false;
			}	//end with
			// set correlation to baseline fuel economy to 1:
			pathwayMC.parameters_area.area.correlation.text = "1";
			this.correlation = 1;
			// 'deactivate' check boxes
			pathwayMC.parameters_area.area.manual_input_checkbox.onRelease = function() {
			};
			pathwayMC.parameters_area.area.manual_input_checkbox.onRollOver = function() {
			};
			pathwayMC.parameters_area.area.manual_input_checkbox.onRollOut = function() {
			};
			pathwayMC.parameters_area.area.manual_input_checkbox.gotoAndStop(2);
			pathwayMC.pathway_area.area.display_relative_checkbox.onRelease = function() {
			};
			pathwayMC.pathway_area.area.display_relative_checkbox.onRollOver = function() {
			};
			pathwayMC.pathway_area.area.display_relative_checkbox.onRollOut = function() {
			};
			pathwayMC.pathway_area.area.display_relative_checkbox.gotoAndStop(2);
			// 'deactivate close button (can't close baseline pathway):
			pathwayMC.title_bar.close_button.enabled = false;
		} else{
			my_fmt.italic = false;
			// activate 'Correlation to Baseline Fuel Economy' input field:
			pathwayMC.parameters_area.area.correlation.type = "input";
			pathwayMC.parameters_area.area.correlation.backgroundColor = 0xFFFFFF;
			//activate buttons:
			pathwayMC.parameters_area.area.set_inputs_button.enabled = true;
			pathwayMC.parameters_area.area.clear_inputs_button.enabled = true;
			// 'activate' pathway's 'Vehicle Stock' input fields:
			if (pathwayMC.parameters_area.area.manual_input_checkbox.isChecked) {
				setManual();
				pathwayMC.parameters_area.area.manual_input_checkbox.gotoAndStop(3);
			} else{
				setExpo();
				pathwayMC.parameters_area.area.manual_input_checkbox.gotoAndStop(1);
			}
			if (pathwayMC.pathway_area.area.display_relative_checkbox.isChecked) {
				setRelative();
				pathwayMC.pathway_area.area.display_relative_checkbox.gotoAndStop(3);
			} else{
				setAbsolute();
				pathwayMC.pathway_area.area.display_relative_checkbox.gotoAndStop(1);
			}
			// 'activate' check boxes:
			var owner:PathwayObj = this;
			pathwayMC.parameters_area.area.manual_input_checkbox.onRelease = function() {
				owner.checkBoxClickEvent(this);
			};
			pathwayMC.parameters_area.area.manual_input_checkbox.onRollOver = function() {
				owner.checkBoxRollOverEvent(this);
			};
			pathwayMC.parameters_area.area.manual_input_checkbox.onRollOut = function() {
				owner.checkBoxRollOutEvent(this);
			};
			pathwayMC.pathway_area.area.display_relative_checkbox.onRelease = function() {
				owner.checkBoxClickEvent(this);
			};
			pathwayMC.pathway_area.area.display_relative_checkbox.onRollOver = function() {
				owner.checkBoxRollOverEvent(this);
			};
			pathwayMC.pathway_area.area.display_relative_checkbox.onRollOut = function() {
				owner.checkBoxRollOutEvent(this);
			};
			// 'activate close button:
			pathwayMC.title_bar.close_button.enabled = true;
			
		}
		this.pathwayMC.title_bar.txt.descr.setTextFormat(my_fmt);
		this.pathwayMC.title_bar.txt.descr.setNewTextFormat(my_fmt);
//trace("  " + this.pathwayMC.title_bar.txt.descr.getTextFormat().italic + "("+my_fmt.italic+")");
	}
	
	function setManual(){
trace(" ...setManual");
		with(pathwayMC.parameters_area){
			area.init_year.type = "dynamic";
			area.init_year.backgroundColor = 0xCCCCCC;
			area.init_value.type = "dynamic";
			area.init_value.backgroundColor = 0xCCCCCC;
			area.growth_rate.type = "dynamic";
			area.growth_rate.backgroundColor = 0xCCCCCC;
			area.stock_2005.type = "input";
			area.stock_2005.backgroundColor = 0xFFFFFF;
			area.stock_2010.type = "input";
			area.stock_2010.backgroundColor = 0xFFFFFF;
			area.stock_2015.type = "input";
			area.stock_2015.backgroundColor = 0xFFFFFF;
			area.stock_2020.type = "input";
			area.stock_2020.backgroundColor = 0xFFFFFF;
			area.stock_2025.type = "input";
			area.stock_2025.backgroundColor = 0xFFFFFF;
			area.stock_2030.type = "input";
			area.stock_2030.backgroundColor = 0xFFFFFF;
			area.init_year.tabEnabled = false;
			area.init_value.tabEnabled = false;
			area.growth_rate.tabEnabled = false;
			area.stock_2005.tabEnabled = true;
			area.stock_2010.tabEnabled = true;
			area.stock_2015.tabEnabled = true;
			area.stock_2020.tabEnabled = true;
			area.stock_2025.tabEnabled = true;
			area.stock_2030.tabEnabled = true;
		}	//end with
	}
	
		function setExpo(){
trace(" ...setExpo");
		with(pathwayMC.parameters_area){
			area.init_year.type = "input";
			area.init_year.backgroundColor = 0xFFFFFF;
			area.init_value.type = "input";
			area.init_value.backgroundColor = 0xFFFFFF;
			area.growth_rate.type = "input";
			area.growth_rate.backgroundColor = 0xFFFFFF;
			area.stock_2005.type = "dynamic";
			area.stock_2005.backgroundColor = 0xCCCCCC;
			area.stock_2010.type = "dynamic";
			area.stock_2010.backgroundColor = 0xCCCCCC;
			area.stock_2015.type = "dynamic";
			area.stock_2015.backgroundColor = 0xCCCCCC;
			area.stock_2020.type = "dynamic";
			area.stock_2020.backgroundColor = 0xCCCCCC;
			area.stock_2025.type = "dynamic";
			area.stock_2025.backgroundColor = 0xCCCCCC;
			area.stock_2030.type = "dynamic";
			area.stock_2030.backgroundColor = 0xCCCCCC;
			area.init_year.tabEnabled = true;
			area.init_value.tabEnabled = true;
			area.growth_rate.tabEnabled = true;
			area.stock_2005.tabEnabled = false;
			area.stock_2010.tabEnabled = false;
			area.stock_2015.tabEnabled = false;
			area.stock_2020.tabEnabled = false;
			area.stock_2025.tabEnabled = false;
			area.stock_2030.tabEnabled = false;
		}	//end with
	}
	
	function setRelative(){
		this.displayRelative = true;
		this.pathwaysSelectionArea.updateWtWResults();
	}
	
	function setAbsolute(){
		this.displayRelative = false;
		this.pathwaysSelectionArea.updateWtWResults();
	}
	
	
	//Watch and Lock methods:
	function lock(obj:Object, toLock:String){
		if(obj.watch(toLock, lockCallback) == false){
			trace("(PathwayObj.954)  Error: WATCH FUNCTION NOT SET! variable = " + toLock);
		}
	}
	function lockOnce(obj:Object, toLock:String){
		var temp:Array = new Array(obj, toLock);
		if(obj.watch(toLock, lockOnceCallback, temp) == false){
			trace("(PathwayObj.959)  Error: WATCH FUNCTION NOT SET! variable = " + toLock);
		}
	}
	function unlock(obj:Object, toUnlock:String){
//trace("(PathwayObj.unlock)  unlocking: " + toUnlock);		
		obj.unwatch(toUnlock);
	}
	
	function unlockVariables(){
		unlock(pathwayMC.parameters_area, "correlationInput");
		//...
	}
	
	//If this function is used as the callback function in a watch() function set to watch a variable
	//it will prevent the variable from being changed, essentially 'locking' the variable.  
	//(This function is needed because some bit of code in Flash somewhere is changing _collapsed parameter of the pathway_area and paramaters_area when it's not supposed to! 
	//It's not a line in my code but must be somewhere else in the code Flash executes behind the scenes.  Damn you Flash!)
	function lockCallback(prop, oldVal, newVal, userData){
//trace("\n(PathwayObj.lockVariable) Something's trying to change a locked variable! " + oldVal + " -> " + newVal + "\n");
		return oldVal;
	}
	
	//This function locks the variable and prevents it from being changed the first time something tries to change it.  After the first attempt to change the variable,
	//this function unlocks the variable.  This function only prevents the first attempt to change the locked variable.
	//The userData parameter should be an array containing two elements, the object and variable to unlock.
	function lockOnceCallback(prop, oldVal, newVal, userData){
//trace("\n(PathwayObj.lockVariable) Something's trying to change a locked variable! " + String(userData[1]) + ": " + oldVal + " -> " + newVal + "\n");
//trace("(PathwayObj.lockVariable) unlocking " +  String(userData[1]));		
		Object(userData[0]).unwatch(String(userData[1]));
		//unlock(userData[0], String(userData[1]));		
		return oldVal;
	}
	
	
	function watchVariable(prop, oldVal, newVal, userData){
//trace("\n(PathwayObj.watchVariable) Something's trying to change a watched variable! " + oldVal + " -> " + newVal + "\n");
		return newVal;
	}
	
}  	//end class
